# CHANGELOG

<!-- version list -->

## v1.0.1 (2026-02-17)

### Bug Fixes

- Windows svc.cmd shell=True and rename CLI to gh-runners
  ([#6](https://github.com/nazq/gh_runners/pull/6),
  [`bdbb6d9`](https://github.com/nazq/gh_runners/commit/bdbb6d9b4a06b6fe8118480faae630b9b5e964e5))


## v1.0.0 (2026-02-17)

- Initial Release
